========
Crawl4us
========

A Python web crawler looking wildly for tables 🕵️‍♀️ 
 
Installation
------------

Crawl4us is available on `PyPI <https://pypi.python.org/pypi/pyflakes>`_ so it can be installed via `pip <https://pypi.python.org/pypi/pip>`_ ::

    $ pip install crawl4us
  
Usage
------------

.. code:: python

    import crawl4us
    
    # TODO


Changelog
---------
